@@ -13,17 +13,13 @@ if TYPE_CHECKING:
 class MoveType(Protocol):
     item: Item
 
-    def __init__(self, item: Item, view: GtkView):
-        ...
+    def __init__(self, item: Item, view: GtkView): ...
 
-    def start_move(self, pos: Pos) -> None:
-        ...
+    def start_move(self, pos: Pos) -> None: ...
 
-    def move(self, pos: Pos) -> None:
-        ...
+    def move(self, pos: Pos) -> None: ...
 
-    def stop_move(self, pos: Pos) -> None:
-        ...
+    def stop_move(self, pos: Pos) -> None: ...
 
 
 class ItemMove:
