@@ -12,11 +12,8 @@ SetT = TypeVar("SetT", contravariant=True)
 
 
 class TypedProperty(Protocol[GetT, SetT]):
-    def __get__(self, obj: object, type: type | None = ...) -> GetT:
-        ...
+    def __get__(self, obj: object, type: type | None = ...) -> GetT: ...
 
-    def __set__(self, obj: object, value: SetT) -> None:
-        ...
+    def __set__(self, obj: object, value: SetT) -> None: ...
 
-    def __delete__(self, obj: object) -> None:
-        ...
+    def __delete__(self, obj: object) -> None: ...
